@@ -181,6 +181,8 @@ class FastScanCommand:
                         'wavelength': [],
                         'detector_voltage': []}
         self.stopped = threading.Event()
+        self._acqLockDetector = threading.RLock()
+        self._acqLockVcm = threading.RLock()
         self.currentX = None
         self.currentY = None
         self.activeCavity = None
@@ -201,16 +203,20 @@ class FastScanCommand:
         while True:
             if self.stopped.is_set():
                 return
-            self._detectorAcquisitions.append((time.time(), self._controller.adc.read()))
+            with self._acqLockDetector:
+                self._detectorAcquisitions.append((time.time(), self._controller.adc.read()))
             if self.stopped.wait(0.001):
                 return
 
     def record_callback(self, x, y, t):
-        self._vcmAcquisitions.append((t, x, y))
+        with self._acqLockVcm:
+            self._vcmAcquisitions.append((t, x, y))
 
     def clear_registers(self):
-        self._detectorAcquisitions = []
-        self._vcmAcquisitions = []
+        with self._acqLockDetector:
+            self._detectorAcquisitions = []
+        with self._acqLockVcm:
+            self._vcmAcquisitions = []
 
     def execute(self):
         try:
